@@ -9,7 +9,7 @@ use constant _share_dir => File::ShareDir::dist_dir('Alien-Libarchive');
 use constant _alien_libarchive019 => 1;
 
 # ABSTRACT: Build and make available libarchive
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 my $cf = 'Alien::Libarchive::ConfigData';
 
@@ -154,7 +154,7 @@ Alien::Libarchive - Build and make available libarchive
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -166,8 +166,8 @@ Build.PL
  my $alien = Alien::Libarchive->new;
  my $build = Module::Build->new(
    ...
-   extra_compiler_flags => $alien->cflags,
-   extra_linker_flags   => $alien->libs,
+   extra_compiler_flags => [$alien->cflags],
+   extra_linker_flags   => [$alien->libs],
    ...
  );
  
@@ -181,25 +181,17 @@ Makefile.PL
  my $alien = Alien::Libarchive;
  WriteMakefile(
    ...
-   CFLAGS => $alien->cflags,
-   LIBS   => $alien->libs,
+   CCFLAGS => scalar $alien->cflags,
+   LIBS    => [$alien->libs],
  );
 
-FFI::Raw
+FFI::Platypus
 
  use Alien::Libarchive;
- use FFI::Raw;
+ use FFI::Platypus;
  
- my($dll) = Alien::Libarchive->new->dlls;
- FFI::Raw->new($dll, 'archive_read_new', FFI::Raw::ptr);
-
-FFI::Sweet
-
- use Alien::Libarchive;
- use FFI::Sweet;
- 
- ffi_lib( Alien::Libarchive->new->dlls );
- attach_function 'archive_read_new', [], _ptr;
+ my $ffi = FFI::Platypus->new(lib => [Alien::Libarchive->new->dlls]);
+ $ffi->attach( archive_read_new => [] => 'opaque' );
 
 =head1 DESCRIPTION
 
